/* Copyright 2010 ESRI
* 
* All rights reserved under the copyright laws of the United States
* and applicable international laws, treaties, and conventions.
* 
* You may freely redistribute and use this sample code, with or
* without modification, provided you include the original copyright
* notice and use restrictions.
* 
* See the use restrictions at http://help.arcgis.com/en/sdk/10.0/usageRestrictions.htm
* 
*/
package arcgissamples.soe.clients;

import java.util.List;

import arcgissamples.soe.BusServicesSOEServiceBindingStub;
import arcgissamples.soe.BusStation;
import arcgissamples.soe.Coordinates;

import com.esri.arcgisws.PointN;

@SuppressWarnings("all")
public class BusServicesSOAPClient
{
	public static void main(String[] args)
	{
		BusServicesSOEServiceBindingStub stub = new BusServicesSOEServiceBindingStub("http://localhost:8399/arcgis/services/portland/MapServer/BusServicesSOE");
		
		System.out.println("\nFinding bus stations within 0.5 miles of location 7652726.886, 678771.121...");
		
		PointN userLocation = new PointN();
		userLocation.setX(7652726.886);
		userLocation.setY(678771.121);
		
		//find bus stations within 0.5 miles of userLocation
		List<BusStation> busStations = stub.findBusStationsNearMe(userLocation, 0.5);
		if (busStations.isEmpty())
		{
			System.out.println("No Bus Stations found. Try a different location.");
		}
		else
		{
			int numPOIS = busStations.size();
			System.out.print("\n" + numPOIS + " bus stops were found: \n");
			BusStation lastStation = null;
			for(BusStation busStation : busStations)
			{
				Coordinates coords = busStation.getCoordinates();
				System.out.println("\nLocation: " + busStation.getLocation() + 
						"\nDirection: " + busStation.getDirection() + 
						"\nRoute Number: " + busStation.getRouteNumber() +
						"\nJurisdiction: " + busStation.getJurisdiction() +
						"\nZip: " + busStation.getZip() + 
						"\nCoordinates: X - " + coords.getX() + " Y - " + coords.getY());
				lastStation = busStation;
				
			}		
			
			//find directions to last bus station from userLocation
			String directions = stub.getDirections(lastStation.getId(), userLocation);
			String[] dirs = directions.split(";");
			System.out.println("\nFinding directions to lat found bus station : \n");
			for(String direction : dirs)
			{
				System.out.println(direction);
			}
		}
	}
}
